import 'dart:math';

import 'package:jeweled/models/game_cell.dart';
import 'package:jeweled/models/settings_game.dart';
import 'package:jeweled/utils/tools.dart';

class GameBoard {
  final List<List<GameCell>> cells;

  GameBoard({
    required this.cells,
  });

  factory GameBoard.createNull() {
    return GameBoard(cells: []);
  }

  factory GameBoard.createRandom(GameSettings gameSettings) {
    final int boardSizeHorizontal = gameSettings.boardSize;
    final int boardSizeVertical = gameSettings.boardSize;
    final int maxValue = gameSettings.colorsCount;

    final rand = Random();

    List<List<GameCell>> cells = [];
    for (int rowIndex = 0; rowIndex < boardSizeVertical; rowIndex++) {
      List<GameCell> row = [];
      for (int colIndex = 0; colIndex < boardSizeHorizontal; colIndex++) {
        int value = 1 + rand.nextInt(maxValue);
        row.add(GameCell(value));
      }
      cells.add(row);
    }

    return GameBoard(
      cells: cells,
    );
  }

  void dump() {
    String horizontalRule = '----';
    for (int i = 0; i < cells[0].length; i++) {
      horizontalRule += '-';
    }

    printlog('Board:');
    printlog(horizontalRule);

    for (int rowIndex = 0; rowIndex < cells.length; rowIndex++) {
      String row = '| ';
      for (int colIndex = 0; colIndex < cells[rowIndex].length; colIndex++) {
        row += cells[rowIndex][colIndex].value.toString();
      }
      row += ' |';

      printlog(row);
    }

    printlog(horizontalRule);
  }

  @override
  String toString() {
    return 'Board(${toJson()})';
  }

  Map<String, dynamic>? toJson() {
    return <String, dynamic>{
      'cells': cells.toString(),
    };
  }
}
