import 'package:flutter/material.dart';
import 'package:flutter_bloc/flutter_bloc.dart';
import 'package:unicons/unicons.dart';

import 'package:jeweled/cubit/game_cubit.dart';
import 'package:jeweled/models/game.dart';

class GameTopIndicatorWidget extends StatelessWidget {
  const GameTopIndicatorWidget({super.key});

  @override
  Widget build(BuildContext context) {
    const Color scoreTextColor = Colors.white;
    const Color movesCountTextColor = Colors.grey;
    const Color availableBlocksCountTextColor = Colors.green;

    const double scoreFontSize = 40;
    const double movesCountFontSize = 15;
    const double availableBlocksCountFontSize = 20;

    return BlocBuilder<GameCubit, GameState>(
      builder: (BuildContext context, GameState gameState) {
        final Game currentGame = gameState.currentGame;

        return Table(
          children: [
            TableRow(
              children: [
                Column(
                  children: [
                    Text(
                      currentGame.score.toString(),
                      style: const TextStyle(
                        fontSize: scoreFontSize,
                        fontWeight: FontWeight.w600,
                        color: scoreTextColor,
                      ),
                    ),
                    Text(
                      currentGame.movesCount.toString(),
                      style: const TextStyle(
                        fontSize: movesCountFontSize,
                        fontWeight: FontWeight.w600,
                        color: movesCountTextColor,
                      ),
                    ),
                  ],
                ),
                Column(
                  children: [
                    Text(
                      currentGame.availableBlocksCount.toString(),
                      style: const TextStyle(
                        fontSize: availableBlocksCountFontSize,
                        fontWeight: FontWeight.w600,
                        color: availableBlocksCountTextColor,
                      ),
                    ),
                    TextButton(
                      child: const Icon(UniconsSolid.refresh),
                      onPressed: () {
                        final GameCubit gameCubit = BlocProvider.of<GameCubit>(context);
                        gameCubit.shuffleColors(currentGame.globalSettings.colorsTheme);
                      },
                    )
                  ],
                ),
              ],
            ),
          ],
        );
      },
    );
  }
}
